from netgen.meshing import Element0D, Element1D, Element2D, MeshPoint, Pnt
from netgen.meshing import Mesh as NetGenMesh
import ngsolve

N = 10
ngmesh = NetGenMesh(dim=1)
pids = []
# Add points to the mesh.
for i in range(N + 1):
    pids.append(ngmesh.Add(MeshPoint(Pnt(i / N, 0, 0))))
# Left half of the domain is material 1, right half material 2.

idx_doml = ngmesh.AddRegion("domain_left", dim=1)
idx_domr = ngmesh.AddRegion("domain_right", dim=1)
    
for i in range(N):
    ngmesh.Add(Element1D([pids[i], pids[i + 1]], index=idx_doml if i < 5 else idx_domr))

# Add BC to the mesh.

idx_l = ngmesh.AddRegion("l", dim=0)
idx_r = ngmesh.AddRegion("r", dim=0)
ngmesh.Add(Element0D(pids[0], index=idx_l))  
ngmesh.Add(Element0D(pids[N], index=idx_r))

# Create NGSolve mesh and refine it once uniformly.
mesh = ngsolve.Mesh(ngmesh)

print ("bnds = ", mesh.GetMaterials())
print ("bnds = ", mesh.GetBoundaries())

for el in mesh.Elements(ngsolve.VOL):
    print (el.index, el.mat)
for el in mesh.Elements(ngsolve.BND):
    print (el.index, el.mat)

for el in mesh.Elements():
    mesh.SetRefinementFlag(el, True)
# throwing an exception
mesh.Refine()

